@@ -7,19 +7,18 @@
 #### movMF: An R Package for Fitting Mixtures of von Mises-Fisher Distributions
 #### http://cran.r-project.org/web/packages/movMF/vignettes/movMF.pdf
 ################################
-
 bic.mixvmf <- function(x, A = 3) {
   ## x contains the data
   ## A is the maximum number of clusters, set to 3 by default
   runtime <- proc.time()
-  n <- dim(x)[1]  ## sample size of the data
+  logn <- log( dim(x)[1] )  ## sample size of the data
   p <- dim(x)[2]  ## dimensionality of the data
   bic <- 1:A
   mod <- vmf(x)
-  bic[1] <-  - 2 * mod$loglik+ p * log(n)  ## BIC assuming one cluster
+  bic[1] <-  - 2 * mod$loglik+ p * logn  ## BIC assuming one cluster
   for (vim in 2:A) {
     a <- mix.vmf(x, vim)  ## model based clustering for some possible clusters
-    bic[vim] <-  -2 * a$loglik + ( (vim - 1) + vim * p ) * log(n)
+    bic[vim] <-  -2 * a$loglik + ( (vim - 1) + vim * p ) * logn
   }  ## BIC for a range of different clusters
   runtime <- proc.time() - runtime
   names(bic) <- 1:A
