@@ -5,7 +5,6 @@
 #### References: Mardia Kanti V. and Jupp Peter E. (2000)
 #### Directional statistics, page 141
 ################################
-
 tang.conc <- function(u, ina, rads = FALSE) {
   ## u contains all the circular data in radians or degrees
   ## ina is an indicator variable of each sample
@@ -27,11 +26,8 @@ tang.conc <- function(u, ina, rads = FALSE) {
     d <- c(d, b)
   }
 
-  for (i in 1:g) {
-    dmi[i] <- mean( d[ ina == i ] )
-    d2[i] <- sum( ( d[ ina == i ] - dmi[i] )^2 )
-  }
-
+  dmi <- Rfast::group.mean(d, ina)
+  d2 <- Rfast::group.var(d, ina) * (ni - 1)
   mdm <- mean(d)
   Ft <- (n - g) * sum(ni * (dmi - mdm)^2) / ( (g - 1) * sum(d2) )
   pvalue <- pf(Ft, g - 1, n - g, lower.tail = FALSE)
